==> ctemplate-0.2.tar.gz: ctemplate-0.2/src/htpl_driver.h <==
/* 
 * Copyright (c) 2006
 *    Aleksey Pesternikov. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR `AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */ 

/*
 * output driver interface
 */

#include <stdio.h>

extern char* tplargs;
extern char* funcname;
extern char* funcprefix;

struct htpl_driver {
  void (*start)(FILE* out);
  void (*finish_header)(FILE* hout, FILE* out);
  void (*out_static_block)(FILE* out, const char* text, int textlen);
  void (*out_dynamic_block)(FILE* out, const char* text, int textlen);
  void (*out_printf_block)(FILE* out, const char* text, int textlen);
};

extern struct htpl_driver apache_driver;
extern struct htpl_driver cgi_driver;
extern struct htpl_driver ff_driver;

==> ctemplate-0.5.tar.gz: ctemplate-0.5/src/htpl_driver.h <==
#ifndef HTPL_DRIVER_H_
#define HTPL_DRIVER_H_
/* 
 * Copyright (c) 2006-2008
 *    Aleksey Pesternikov. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR `AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */ 

/*
 * output driver interface
 */

#include <stdio.h>
#include <string.h>
#include <time.h>

#ifdef __linux__
const char *getprogname(void);
#endif

extern char* tplargs;
const extern char* funcname;
extern const char* funcprefix;

class htpl_driver {
protected:
  FILE* out, *hout;
  time_t start_time;
public:
  virtual void start(FILE* out_, FILE* hout_) {out=out_; hout=hout_;  start_time = time(0); };
  virtual void finish_header()=0;
  virtual void out_static_block(const char* text, int textlen)=0;
  virtual void flush_static_blocks()=0;
  virtual void out_dynamic_block(const char* text, int textlen)=0;
  virtual void out_printf_block(const char* text, int textlen)=0;
};

#endif
